@@ -122,11 +122,13 @@ class PhaseSeries(Word):
             start_date (str): start date of the new phase
             end_date (str): end date of the new phase
             population (int): population value of the start date
-                - if None, initial value will be used
             kwargs: keyword arguments to save as phase information
 
         Returns:
             self
+
+        Notes:
+            if @population is None, initial value will be used.
         """
         # Arguments
         if population is None:
@@ -152,13 +154,20 @@ class PhaseSeries(Word):
                 f"@end_date must be the same or over {min_end_date}, but {end_date} was applied."
             )
         # Add new phase
-        for date_obj in date_series:
-            if date_obj in self.phase_dict.keys():
-                if self.phase_dict[date_obj] != 0:
-                    date_str = date_obj.strftime(self.DATE_FORMAT)
-                    raise KeyError(
-                        f"Phase has been registered for {date_str}.")
-            self.phase_dict[date_obj] = new_id
+        new_phase_dict = {
+            date_obj: new_id
+            for date_obj in date_series
+        }
+        free_date_set = set(k for (k, v) in self.phase_dict.items() if v)
+        intersection = set(new_phase_dict.keys()) & free_date_set
+        if intersection:
+            date_strings = [
+                date_obj.strftime(self.DATE_FORMAT) for date_obj in intersection
+            ]
+            dates_str = ", ".join(date_strings)
+            raise KeyError(
+                f"Phases have been registered for {dates_str}.")
+        self.phase_dict.update(new_phase_dict)
         # Add phase information
         self.info_dict[new_id] = {
             self.TENSE: start_tense,
@@ -213,15 +222,14 @@ class PhaseSeries(Word):
         Summarize the series of phase in a dictionary.
 
         Returns:
-            (dict)
+            (dict): nested dictionary of phase information
                 - key (str): phase number, like 1th, 2nd,...
-                - value (str): {
-                    'Type': (str) 'Past' or 'Future'
-                    'Start': (str) start date of the phase,
-                    'End': (str) end date of the phase,
-                    'Population': (int) population value at the start date
-                    - values added by self.update()
-                }
+                - value (dict): phase information
+                    - 'Type': (str) 'Past' or 'Future'
+                    - 'Start': (str) start date of the phase,
+                    - 'End': (str) end date of the phase,
+                    - 'Population': (int) population value at the start date
+                    - values added by PhaseSeries.update()
         """
         # Convert phase ID to phase name
         info_dict = {
@@ -238,10 +246,12 @@ class PhaseSeries(Word):
         Args:
             target_date (str): target date, like 22Jan2020
             ref_date (str or None): reference date
-                - if None, will use last date of the records
 
         Returns:
             (str): 'Past' or 'Future'
+
+        Notes:
+            If @ref_date is None, the last date of the records will be used.
         """
         target_obj = datetime.strptime(target_date, self.DATE_FORMAT)
         ref_date = self.last_record_date if ref_date is None else ref_date
@@ -258,7 +268,7 @@ class PhaseSeries(Word):
             phase (str): phase name
             kwargs: keyword arguments to add
         """
-        phase_id = phase_id = self._phase_name2id(phase)
+        phase_id = self._phase_name2id(phase)
         self.info_dict[phase_id].update(kwargs)
         return self
 
