@@ -42,7 +42,9 @@ class Scenario(Word):
         # Records
         jhu_data = self.validate_instance(jhu_data, JHUData, name="jhu_data")
         self.jhu_data = jhu_data
-        self.clean_df = jhu_data.cleaned(population=self.population)
+        self.clean_df = jhu_data.subset(
+            country, province=province, population=self.population
+        )
         # Area name
         self.country = country
         self.province = province
@@ -121,26 +123,19 @@ class Scenario(Word):
             name (str): phase series name, 'Main' or user-defined name
             end_date (str): end date of the new phase
             days (int): the number of days to add
-            population (int): population value of the start date
-                - if None, the same as initial value
-            model (covsirphy.ModelBase): ODE model
-                - if None, the model of the last phase will be used
-            kwargs: keyword arguments of ODE model parameters
-                - un-included parameters will be the same as the last phase
-                    - if model is not the same, None
-                    - tau is fixed as the last phase's value
+            population (int or None): population value of the start date
+            model (covsirphy.ModelBase orNone): ODE model
+            kwargs: optional, keyword arguments of ODE model parameters, not including tau value.
 
         Notes:
-            If the phases series has not been registered, new phase series will be created.
-            @end_date or @days must be specified.
-
-        Returns:
-            None
+            - If the phases series has not been registered, new phase series will be created.
+            - @end_date or @days must be specified.
+            - If @popultion is None, initial value will be used.
+            - If @model is None, the model of the last phase will be used.
+            - Tau will be fixed as the last phase's value.
+            - kwargs: Default values are the parameter values of the last phase.
         """
         # Parse arguments
-        if not isinstance(name, str):
-            raise TypeError(
-                f"@name must be a string, but {type(name)} was applied.")
         name = self.MAIN if name == "Main" else name
         if name not in self.series_dict.keys():
             self.series_dict[name] = copy.deepcopy(self.series_dict[self.MAIN])
@@ -242,7 +237,7 @@ class Scenario(Word):
             include_init_phase (bool): whether use initial phase or not
             show_figure (bool): if True, show the result as a figure
             filename (str): filename of the figure, or None (show figure)
-            kwargs: the other keyword arguments of ChangeFinder().run()
+            kwargs: the other keyword arguments will be ignored.
 
         Returns:
             None
@@ -259,7 +254,7 @@ class Scenario(Word):
                 "@n_points argument is un-necessary"
                 " because the number of change points will be automatically determined."
             )
-        finder.run(**kwargs)
+        finder.run()
         phase_series = finder.show(show_figure=show_figure, filename=filename)
         if not set_phases:
             return None
@@ -330,7 +325,7 @@ class Scenario(Word):
         trials = phase_est_dict["Trials"]
         runtime = phase_est_dict["Runtime"]
         print(
-            f"\t{phase} phase with {model.NAME} model finished {trials} in {runtime}."
+            f"\t{phase} phase with {model.NAME} model finished {trials} trials in {runtime}."
         )
         # Return the dictionary of the result of estimation
         return (model, name, phase, estimator, phase_est_dict)
@@ -545,7 +540,7 @@ class Scenario(Word):
         df = self.series_dict[name].summary()
         simulator = ODESimulator(
             self.country,
-            province="-" if self.province is None else self.province
+            province=self.UNKNOWN if self.province is None else self.province
         )
         start_objects = list()
         for phase in df.index:
@@ -576,7 +571,7 @@ class Scenario(Word):
                 y0_dict=y0_dict_phase
             )
         simulator.run()
-        first_date = df.loc[self.num2str(1), self.START]
+        first_date = start_objects[0].strftime(self.DATE_FORMAT)
         dim_df = simulator.dim(self.tau, first_date)
         return dim_df, start_objects
 
@@ -612,7 +607,7 @@ class Scenario(Word):
         Return subset of summary.
 
         Args:
-            targets (list[str]/str): parameters to show (Rt etc.)
+            targets (list[str] or str): parameters to show (Rt etc.)
             name (str): phase series name
             divide_by_first (bool): if True, divide the values by 1st phase's values
             show_box_plot (bool): if True, box plot. if False, line plot
@@ -663,7 +658,7 @@ class Scenario(Word):
         line_plot(
             _df, title=title,
             xlabel="Phase", ylabel=str(), math_scale=False, h=h,
-            show_figure=show_figure, filename=filename
+            filename=filename
         )
         return df
 
