@@ -19,7 +19,7 @@ class ChangeFinder(Word):
         clean_df (pandas.DataFrame): cleaned data
 
             Index:
-                reset index
+                - reset index
             Columns:
                 - Date (pd.TimeStamp): Observation date
                 - Country (str): country/region name
@@ -145,7 +145,7 @@ class ChangeFinder(Word):
             # Get min value for vline
             vlines.append(df[self.R].min())
             # Rename the columns
-            phase = phase.replace("0th", self.INITIAL)
+            phase = self.INITIAL if phase == "0th" else phase
             df = df.rename({f"{self.S}{self.P}": f"{phase}{self.P}"}, axis=1)
             df = df.rename({f"{self.S}{self.A}": f"{phase}{self.A}"}, axis=1)
             df = df.rename({f"{self.R}": f"{phase}_{self.R}"}, axis=1)
@@ -188,21 +188,25 @@ class ChangeFinder(Word):
     def get_dates(self, clean_df, population, country, province):
         """
         Get dates from the dataset.
+
         Args:
             clean_df (pandas.DataFrame): cleaned data
-                        Index:
-                            reset index
-                        Columns:
-                            - Date (pd.TimeStamp): Observation date
-                            - Country (str): country/region name
-                            - Province (str): province/prefecture/sstate name
-                            - Confirmed (int): the number of confirmed cases
-                            - Infected (int): the number of currently infected cases
-                            - Fatal (int): the number of fatal cases
-                            - Recovered (int): the number of recovered cases
+                Index:
+                - reset index
+
+                Columns:
+                    - Date (pd.TimeStamp): Observation date
+                    - Country (str): country/region name
+                    - Province (str): province/prefecture/sstate name
+                    - Confirmed (int): the number of confirmed cases
+                    - Infected (int): the number of currently infected cases
+                    - Fatal (int): the number of fatal cases
+                    - Recovered (int): the number of recovered cases
+
             population (int): initial value of total population in the place
             country (str): country name
             province (str): province name
+
         Returns:
             (list[str]): list of dates, like 22Jan2020
         """
@@ -214,12 +218,14 @@ class ChangeFinder(Word):
     def _read_population_data(self, dates, population, change_dict=None):
         """
         Make population dictionary easy to use in this class.
+
         Args:
             dates (list[str]): list of dates, like 22Jan2020
             population (int): initial value of total population in the place
             change_dict (dict): dictionary of total population
                     - key (str): start date of population change
                     - value (int or None): total population
+
         Returns:
             (dict)
                 - key (str): date, like 22Jan2020
