@@ -44,9 +44,9 @@ class SIR(ModelBase):
 
     def __init__(self, population, rho, sigma):
         # Total population
-        if not isinstance(population, int):
-            raise TypeError("@population must be an integer.")
-        self.population = population
+        self.population = self.validate_natural_int(
+            population, name="population"
+        )
         # Non-dim parameters
         self.rho = rho
         self.sigma = sigma
