@@ -49,9 +49,9 @@ class SIRF(ModelBase):
 
     def __init__(self, population, theta, kappa, rho, sigma):
         # Total population
-        if not isinstance(population, int):
-            raise TypeError("@population must be an integer.")
-        self.population = population
+        self.population = self.validate_natural_int(
+            population, name="population"
+        )
         # Non-dim parameters
         self.theta = theta
         self.kappa = kappa
