@@ -55,9 +55,9 @@ class SIRFV(ModelBase):
     def __init__(self, population, theta, kappa, rho, sigma,
                  omega=None, v_per_day=None):
         # Total population
-        if not isinstance(population, int):
-            raise TypeError("@population must be an integer.")
-        self.population = population
+        self.population = self.validate_natural_int(
+            population, name="population"
+        )
         # Non-dim parameters
         self.theta = theta
         self.kappa = kappa
