@@ -12,8 +12,8 @@ class TestChangeFinder(object):
         ["Italy", "Japan", "United States", "India", "New Zealand"]
     )
     def test_find(self, jhu_data, population_data, country):
-        clean_df = jhu_data.cleaned()
         population = population_data.value(country)
+        clean_df = jhu_data.subset(country, population=population)
         change_finder = ChangeFinder(
             clean_df, population, country=country
         )
